# Welcome to `zizmor`'s documentation!

[![CI](https://github.com/woodruffw/zizmor/actions/workflows/ci.yml/badge.svg)](https://github.com/woodruffw/zizmor/actions/workflows/ci.yml)
[![Crates.io](https://img.shields.io/crates/v/zizmor)](https://crates.io/crates/zizmor)
[![Packaging status](https://repology.org/badge/tiny-repos/zizmor.svg)](https://repology.org/project/zizmor/versions)
[![GitHub Sponsors](https://img.shields.io/github/sponsors/woodruffw?style=flat&logo=githubsponsors&labelColor=white&color=white)](https://github.com/sponsors/woodruffw)

:rainbow: Hello, and welcome to `zizmor`'s documentation! :rainbow:

`zizmor` is a static analysis tool for GitHub Actions. It can find
many common security issues in typical GitHub Actions CI/CD setups.

Go right to our [Installation Steps](./installation.md), and then to
[Quickstart](./quickstart.md) or [Usage Recipes](./usage.md) to
learn more about how to use `zizmor` locally or in your CI/CD.

<figure markdown="1">
![](./assets/zizmor-demo.gif)
</figure>
